typewriter
open | /demo/typewriter.html |
assertTextPresent | Typewriter |
assertText | pattern | This is our first lesson at the SnowSprint
shiftKeyDown |  |
keyDown | field | \16
waitForText | key_116 | T
assertText | key_116 | T
keyDown | field | T
waitForAttribute | key_116@class | key active
assertAttribute | key_116@class | key active
assertText | pattern | his is our first lesson at the SnowSprint
keyUp | field | T
waitForAttribute | key_116@class | key
assertAttribute | key_116@class | key
keyUp | field | \16
shiftKeyUp |  |
keyDown | field | h
waitForAttribute | key_104@class | key active
assertAttribute | key_104@class | key active
assertText | pattern | is is our first lesson at the SnowSprint
keyUp | field | h
waitForAttribute | key_104@class | key
assertAttribute | key_104@class | key
mouseDown | key_105 |
waitForAttribute | key_105@class | key active
assertAttribute | key_105@class | key active
assertText | pattern | s is our first lesson at the SnowSprint
mouseUp | key_105 |
waitForAttribute | key_105@class | key
assertAttribute | key_105@class | key
click | lesson_1 |
waitForText | pattern | KSS is a generic javascript AJAX framework
assertText | pattern | KSS is a generic javascript AJAX framework